<?php

// Set character encoding headers
header('Content-Type: text/html; charset=utf-8');

include "connection.php";

// Set timezone to Bangladesh Standard Time (BST)
date_default_timezone_set('Asia/Dhaka');

// Set charset for database connection
mysqli_set_charset($conn, "utf8mb4");

if (isset($_POST['notificationTitle'])) {

    // Get the POST data
    $notificationTitle = trim($_POST['notificationTitle']);
    $notificationDes = trim($_POST['notificationDes']);
    
    // Get Bangladesh time in 12-hour format (Date_default_timezone_set('Asia/Dhaka');
    $notificationDate = date('Y-m-d h:i:s A');
    
    $view_count = isset($_POST['view_count']) ? $_POST['view_count'] : 0;

    // Check if the same notification already exists
    $checkStmt = $conn->prepare("SELECT COUNT(*) FROM notifications WHERE notificationTitle = ? AND notificationDes = ?");
    $checkStmt->bind_param("ss", $notificationTitle, $notificationDes);
    $checkStmt->execute();
    $checkStmt->bind_result($count);
    $checkStmt->fetch();
    $checkStmt->close();

    if ($count > 0) {
        
        die("Duplicate Data Insert");
    }
  

    // Define the target directory for images
    $target_dir = "Images/";

    // Ensure the directory exists and is writable
    if (!is_dir($target_dir) && !mkdir($target_dir, 0755, true)) {
        die("Failed to create directory!");
    }

    if (!is_writable($target_dir)) {
        die("Directory is not writable!");
    }

    // Handle single image upload
    $imageStore = null;
    if (isset($_FILES["image"]) && $_FILES["image"]["error"] === UPLOAD_ERR_OK) {
        $imageStore = rand() . "_" . time() . ".jpeg";
        $target_file = $target_dir . $imageStore;

        if (!move_uploaded_file($_FILES["image"]["tmp_name"], $target_file)) {
            die("Failed to move uploaded file! Check folder permissions.");
        }
    } else {
        if (isset($_FILES["image"]["error"])) {
            die("File upload error: " . $_FILES["image"]["error"]);
        } else {
            die("No file uploaded!");
        }
    }

    // Prepare the SQL statement to prevent SQL injection
    $stmt = $conn->prepare("INSERT INTO notifications (notificationTitle, notificationDes, notificationDate, view_count, notificationPhoto) 
                            VALUES (?, ?, ?, ?, ?)");
    if ($stmt === false) {
        die("Error preparing statement: " . $conn->error);
    }

    $stmt->bind_param(
        "sssds",
        $notificationTitle,
        $notificationDes,
        $notificationDate,
        $view_count,
        $imageStore
    );

    // Execute the query
    if ($stmt->execute()) {
        echo "Notification inserted successfully!";
    } else {
        die("Data insertion failed: " . $stmt->error);
    }

    // Close the statement
    $stmt->close();
}

// Close the database connection
$conn->close();

?>
