<?php
// Database connection credentials
include 'db_connect.php';

// Fetch the latest notice
$sql = "SELECT notice FROM notice_table ORDER BY id DESC LIMIT 1"; 
$result = $conn->query($sql);

$notice = '';
if ($result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $notice = $row['notice'];
} else {
    $notice = 'No notice available';
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Panel - Notice Management</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            text-align: center;
            margin: 20px;
            background: #f4f4f4;
        }
        .container {
            width: 80%;
            margin: auto;
        }
        .add-form {
            background: #fff;
            padding: 20px;
            margin-bottom: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        textarea, button {
            width: 90%;
            padding: 8px;
            margin-top: 5px;
        }
        button {
            background: blue;
            color: white;
            border: none;
            cursor: pointer;
            width: 100px;
            border-radius: 5px;
        }
        .saving {
            font-weight: bold;
            color: orange;
            font-size: 1.2em;
        }
    </style>
</head>
<body>

    <div class="container">
        <h1>Admin Panel - Manage Notice</h1>

        <!-- Form to Edit Notice -->
        <form class="add-form" id="noticeForm">
            <h3>Edit Notice</h3>
            <textarea id="noticeText" name="notice" rows="5" required><?php echo $notice; ?></textarea><br><br>
            <button type="submit">Save</button>
        </form>

        <!-- Display current notice -->
        <div>
            <h2>Current Notice</h2>
            <p id="currentNotice"><?php echo $notice; ?></p>
        </div>

        <!-- Display saving status message -->
        <div id="savingStatus" class="saving" style="display: none;">Saving...</div>
    </div>

    <script>
        document.getElementById('noticeForm').addEventListener('submit', function(event) {
            event.preventDefault();
            const noticeText = document.getElementById('noticeText').value;
            const savingStatus = document.getElementById('savingStatus');
            
            // Show the "Saving..." message
            savingStatus.style.display = 'block';
            
            // Send the updated notice to the server to save it
            fetch('update_notice.php', {
                method: 'POST',
                headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify({ notice: noticeText })
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    // After successful save, update the displayed notice
                    document.getElementById('currentNotice').textContent = noticeText;  
                    alert('Notice updated successfully');
                } else {
                    alert('Failed to update notice');
                }
                // Hide the "Saving..." message
                savingStatus.style.display = 'none';
            })
            .catch(error => {
                console.error('Error:', error);
                alert('Error updating the notice');
                savingStatus.style.display = 'none';
            });
        });
    </script>

</body>
</html>
