<?php
// Database connection credentials
include 'db_connect.php';

// SQL query to fetch all image URLs in ascending order
$sql = "SELECT id, image_url FROM slider_images ORDER BY id ASC";
$result = $conn->query($sql);

$images = [];
if ($result->num_rows > 0) {
    // Fetch all rows and store them in the images array
    while ($row = $result->fetch_assoc()) {
        $images[] = $row;
    }
} else {
    $images = []; // If no images found
}

// Close the database connection
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Panel - Manage Images</title>
    <style>
        body { font-family: Arial, sans-serif; text-align: center; margin: 20px; background: #f4f4f4; }
        .container { width: 80%; margin: auto; }
        .add-form, .card { background: #fff; padding: 20px; margin-bottom: 20px; border-radius: 10px; box-shadow: 0 0 10px rgba(0, 0, 0, 0.1); }
        input, button { width: 90%; padding: 8px; margin-top: 5px; }
        button { background: blue; color: white; border: none; cursor: pointer; width: 100px; border-radius: 5px; }
        .card img { width: 100%; max-height: 200px; object-fit: cover; border-radius: 5px; }
        .btn-container { display: flex; justify-content: space-between; margin-top: 10px; }
        .edit-btn { background: orange; }
        .delete-btn { background: red; }
        #loading { display: none; color: blue; font-size: 16px; }
        .image-preview { max-width: 100%; margin-top: 15px; max-height: 200px; object-fit: cover; border-radius: 5px; }
    </style>
</head>
<body>

    <div class="container">
        <h1>Admin Panel - Manage Images</h1>

        <!-- Form to Add/Edit Image -->
        <form class="add-form" id="imageForm" enctype="multipart/form-data">
            <h3 id="formTitle">Add New Image</h3>
            <input type="hidden" id="imageId" name="id">
            <input type="file" name="image" id="image" accept="image/*" required><br><br>
            <img id="imagePreview" class="image-preview" src="" alt="" style="display: none;">
            <div id="loading">Uploading...</div><br>
            <button type="submit">Save</button>
        </form>

        <!-- Display Images as Cards -->
        <div class="promotions" id="imagesContainer">
            <?php foreach ($images as $image): ?>
            <div class="card" id="card-<?= $image['id']; ?>">
                <img src="<?= $image['image_url']; ?>" alt="Promotion Image">
                <div class="btn-container">
                    <button class="edit-btn" onclick="editImage(<?= $image['id']; ?>, '<?= $image['image_url']; ?>')">Edit</button>
                    <button class="delete-btn" onclick="deleteImage(<?= $image['id']; ?>)">Delete</button>
                </div>
            </div>
            <?php endforeach; ?>
        </div>
    </div>

    <script>
        let editingId = null;

        // Preview the selected image before uploading
        document.getElementById("image").addEventListener("change", function(event) {
            const file = event.target.files[0];
            if (file) {
                const reader = new FileReader();
                reader.onload = function(e) {
                    const preview = document.getElementById("imagePreview");
                    preview.src = e.target.result;
                    preview.style.display = "block"; // Show the image
                };
                reader.readAsDataURL(file);
            }
        });

        // Submit Form Using AJAX for Adding/Editing Images
        document.getElementById("imageForm").addEventListener("submit", function(event) {
            event.preventDefault();

            let formData = new FormData(this);
            if (editingId !== null) {
                formData.append("id", editingId);
            }

            // Show the uploading message
            document.getElementById("loading").style.display = "block";

            fetch("manage_image.php", {
                method: "POST",
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                // Hide the loading message
                document.getElementById("loading").style.display = "none";

                if (data.success) {
                    alert(data.message);
                    location.reload();
                } else {
                    alert(data.message);
                }
            })
            .catch(error => {
                console.error("Error:", error);
                document.getElementById("loading").style.display = "none"; // Hide on error
            });
        });

        // Edit Function
        function editImage(id, imageUrl) {
            editingId = id;
            document.getElementById("imageId").value = id;
            document.getElementById("formTitle").textContent = "Edit Image";
            document.getElementById("image").value = ""; // Reset file input
            // Show the current image
            document.getElementById("imagePreview").src = imageUrl;
            document.getElementById("imagePreview").style.display = "block";
            alert("You can now choose a new image to replace the current one.");
        }

        // Delete Function Using AJAX
        function deleteImage(id) {
            if (confirm("Are you sure you want to delete this image?")) {
                fetch("delete_image.php", {
                    method: "POST",
                    headers: { "Content-Type": "application/json" },
                    body: JSON.stringify({ id: id })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        alert(data.message);
                        document.getElementById("card-" + id).remove();
                    } else {
                        alert(data.message);
                    }
                })
                .catch(error => console.error("Error:", error));
            }
        }
    </script>

</body>
</html>
