<?php

// Set character encoding headers
header('Content-Type: text/html; charset=utf-8');

include 'db_connect.php';

// Force timezone setup
date_default_timezone_set('Asia/Dhaka');

// Set charset for database connection
mysqli_set_charset($conn, "utf8mb4");

if (isset($_POST['id']) && isset($_POST['notificationTitle']) && isset($_POST['notificationDes'])) {

    // Get the POST data
    $id = $_POST['id']; // Record ID to update
    $notificationTitle = trim($_POST['notificationTitle']);
    $notificationDes = trim($_POST['notificationDes']);

    // Get Bangladesh time using DateTime for better accuracy
    $dt = new DateTime("now", new DateTimeZone('Asia/Dhaka'));
    $notificationDate = $dt->format('Y-m-d h:i:s A');

    // Define the target directory for images
    $target_dir = "Images/";

    // Ensure the directory exists and is writable
    if (!is_dir($target_dir)) {
        mkdir($target_dir, 0755, true);
    }

    // Initialize image store variable
    $imageStore = null;

    // Check if a new image is uploaded
    if (isset($_FILES["notificationPhoto"]) && $_FILES["notificationPhoto"]["error"] === UPLOAD_ERR_OK) {
        $imageStore = rand() . "_" . time() . ".jpeg";
        $target_file = $target_dir . $imageStore;

        // Save the image
        if (!move_uploaded_file($_FILES["notificationPhoto"]["tmp_name"], $target_file)) {
            die("Image upload failed!");
        }
    }

    // Prepare the SQL statement for update
    $sql = "UPDATE notifications 
            SET notificationTitle = ?, 
                notificationDes = ?, 
                notificationDate = ?";

    // Append image update if a new image is uploaded
    if ($imageStore) {
        $sql .= ", notificationPhoto = ?";
    }

    $sql .= " WHERE id = ?";

    // Prepare the statement
    $stmt = $conn->prepare($sql);

    if ($imageStore) {
        $stmt->bind_param("ssssi", $notificationTitle, $notificationDes, $notificationDate, $imageStore, $id);
    } else {
        $stmt->bind_param("sssi", $notificationTitle, $notificationDes, $notificationDate, $id);
    }

    // Execute the query
    if ($stmt->execute()) {
        echo "Notification updated successfully!";
    } else {
        echo "Data update failed: " . $stmt->error;
    }

    // Close the statement
    $stmt->close();
}

// Close the database connection
$conn->close();

?>
