<?php
// Database connection parameters
include 'db_connect.php';

// Collecting input data
$user_id = isset($_POST['user_id']) ? $conn->real_escape_string($_POST['user_id']) : null;
$name = isset($_POST['name']) ? $conn->real_escape_string($_POST['name']) : null;
$phone = isset($_POST['phone']) ? $conn->real_escape_string($_POST['phone']) : null;
$password = isset($_POST['password']) ? $_POST['password'] : null;
$address = isset($_POST['address']) ? $conn->real_escape_string($_POST['address']) : null;
$image_url = isset($_POST['image_url']) ? $_POST['image_url'] : null; // Base64-encoded image string (optional)

// Validate required fields
if (!$user_id || !$name || !$phone || !$password || !$address) {
    die("Error: Missing required fields.");
}

// Check if user exists by ID
$sql = "SELECT * FROM users WHERE id=?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("s", $user_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    // User exists, fetch the old image URL
    $row = $result->fetch_assoc();
    $old_image_url = $row['image_url'];

    // If a new image is provided
    if (!empty($image_url)) {
        // Decode the new base64 image and save it
        $image_data = base64_decode($image_url);
        $image_name = uniqid("profile_", true) . ".png";
        $image_path = "uploads/" . $image_name;

        if (file_put_contents($image_path, $image_data) === false) {
            die("Error saving the new image.");
        }

        // Construct the new image URL
        $image_url = "https://bdappstore.com/akhaura_online_sheba/" . $image_path;

        // Remove the old image from the server if it exists
        if (!empty($old_image_url)) {
            $old_image_path = str_replace("https://bdappstore.com/akhaura_online_sheba/", "", $old_image_url);
            if (file_exists($old_image_path) && !unlink($old_image_path)) {
                error_log("Error deleting old image: $old_image_path");
            }
        }
    } else {
        // If no new image is provided, keep the old image URL
        $image_url = $old_image_url;
    }


    // SQL to update user profile
    $update_sql = "UPDATE users SET name=?, phone=?, password=?, address=?, image_url=? WHERE id=?";
    $update_stmt = $conn->prepare($update_sql);
    $update_stmt->bind_param("ssssss", $name, $phone, $password, $address, $image_url, $user_id);

    if ($update_stmt->execute()) {
        echo "Profile updated successfully!";
    } else {
        echo "Error updating profile: " . $conn->error;
    }
} else {
    echo "User not found!";
}

$conn->close();
?>
