<?php
// Database connection parameters
include 'db_connect.php';

header('Content-Type: application/json; charset=utf-8');

// Validate input
if (isset($_GET['id']) && is_numeric($_GET['id'])) {
    $user_id = intval($_GET['id']); // Use intval() to ensure a numeric value

    // Fetch user data using a prepared statement
    $stmt = $conn->prepare("SELECT id, name, phone, password, address, image_url FROM users WHERE id = ?");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $row = $result->fetch_assoc();
        $response = array(
            "status" => "success",
            "user_id" => $row['id'],
            "user_name" => $row['name'],
            "user_phone" => $row['phone'],
            "user_password" => $row['password'], // Include password
            "user_address" => $row['address'],
            "user_image_url" => $row['image_url']
        );
        echo json_encode($response, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES); // Clean JSON
    } else {
        echo json_encode(array("status" => "failed", "message" => "User not found"), JSON_UNESCAPED_UNICODE);
    }

    $stmt->close();
} else {
    echo json_encode(array("status" => "failed", "message" => "Invalid or missing User ID"), JSON_UNESCAPED_UNICODE);
}

// Close connection
$conn->close();
?>
