<?php

// Set character encoding headers
header('Content-Type: application/json; charset=utf-8');

include 'connection.php';

// Set charset for database connection
mysqli_set_charset($conn, 'utf8mb4');

// Initialize an empty array to store the response data
$data = [];

// Set timezone to Bangladesh Standard Time (BST)
date_default_timezone_set('Asia/Dhaka');

// SQL query to select all records from the notifications table
$sql = "SELECT id, notificationTitle, notificationDes, notificationDate, view_count, notificationPhoto FROM notifications";
$result = mysqli_query($conn, $sql);

// Check if the query was successful
if ($result) {
    // Loop through the result set and build the data array
    while ($item = mysqli_fetch_assoc($result)) {
        // Convert the notification date to the desired format (if needed)
        $notificationDate = new DateTime($item['notificationDate'], new DateTimeZone('UTC')); // Treat it as UTC
        $notificationDate->setTimezone(new DateTimeZone('Asia/Dhaka')); // Convert to Asia/Dhaka timezone
        $formattedDate = $notificationDate->format('Y-m-d H:i:s');  // 24-hour format for the time

        $info = [
            'id'                => $item['id'],
            'notificationTitle' => $item['notificationTitle'],
            'notificationDes'   => $item['notificationDes'],
            'notificationDate'  => $formattedDate,  // Use formatted date
            'view_count'        => $item['view_count'],
            'notificationPhoto' => $item['notificationPhoto'],
        ];
        array_push($data, $info);
    }

    // Return the data as a JSON response
    echo json_encode($data, JSON_UNESCAPED_UNICODE);
} else {
    // Return an error message if the query failed
    echo json_encode(['error' => 'Failed to retrieve data from the database.'], JSON_UNESCAPED_UNICODE);
}

// Close the database connection
mysqli_close($conn);

?>
